@@ -76,10 +76,6 @@ You can also look for information at:
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=MyModule>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/MyModule>
-
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/MyModule>
