@@ -22,7 +22,7 @@ Test::Run::CmdLine - Analyze tests from the command line using Test::Run
 
 use vars (qw($VERSION));
 
-$VERSION = '0.0131';
+$VERSION = '0.0132';
 
 use Moose;
 
@@ -485,10 +485,6 @@ You can also look for information at:
 
 =over 4
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Test::Run::CmdLine>
-
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Test::Run::CmdLine>
