@@ -5,7 +5,7 @@ use warnings;
 
 use vars (qw($VERSION));
 
-$VERSION = '0.0131';
+$VERSION = '0.0132';
 
 use parent 'Test::Run::Trap::Obj';
 
@@ -71,10 +71,6 @@ You can also look for information at:
 
 =over 4
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Test::Run::CmdLine>
-
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Test::Run::CmdLine>
