@@ -3,10 +3,12 @@ package Test::Run::CmdLine::Plugin::BarField;
 use strict;
 use warnings;
 
-sub _init
+use Moose;
+
+sub BUILD
 {
     my $self = shift;
-    $self->next::method(@_);
+
     $self->add_to_backend_plugins("BarField");
 }
 
